#ifndef NT2_INCLUDE_FUNCTIONS_LEVENBERG_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LEVENBERG_HPP_INCLUDED

#include <nt2/optimization/include/functions/levenberg.hpp>

#endif
